@@ -1,7 +1,7 @@
 /*
     data.c - Part of libsensors, a Linux library for reading sensor data.
     Copyright (c) 1998, 1999  Frodo Looijaard <frodol@dds.nl>
-    Copyright (C) 2007        Jean Delvare <khali@linux-fr.org>
+    Copyright (C) 2007, 2009  Jean Delvare <khali@linux-fr.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -33,8 +33,13 @@
 
 const char *libsensors_version = LM_VERSION;
 
+char **sensors_config_files = NULL;
+int sensors_config_files_count = 0;
+int sensors_config_files_max = 0;
+
 sensors_chip *sensors_config_chips = NULL;
 int sensors_config_chips_count = 0;
+int sensors_config_chips_subst = 0;
 int sensors_config_chips_max = 0;
 
 sensors_bus *sensors_config_busses = NULL;
@@ -49,7 +54,10 @@ sensors_bus *sensors_proc_bus = NULL;
 int sensors_proc_bus_count = 0;
 int sensors_proc_bus_max = 0;
 
-static int sensors_substitute_chip(sensors_chip_name *name, int lineno);
+void sensors_free_chip_name(sensors_chip_name *chip)
+{
+	free(chip->prefix);
+}
 
 /*
    Parse a chip name to the internal representation. These are valid names:
@@ -85,7 +93,7 @@ int sensors_parse_chip_name(const char *name, sensors_chip_name *res)
 			return -SENSORS_ERR_CHIP_NAME;
 		res->prefix = strndup(name, dash - name);
 		if (!res->prefix)
-			sensors_fatal_error("sensors_parse_chip_name",
+			sensors_fatal_error(__func__,
 					    "Allocating name prefix");
 		name = dash + 1;
 	}
@@ -111,6 +119,8 @@ int sensors_parse_chip_name(const char *name, sensors_chip_name *res)
 		res->bus.type = SENSORS_BUS_TYPE_SPI;
 	else if (!strncmp(name, "virtual", dash - name))
 		res->bus.type = SENSORS_BUS_TYPE_VIRTUAL;
+	else if (!strncmp(name, "acpi", dash - name))
+		res->bus.type = SENSORS_BUS_TYPE_ACPI;
 	else
 		goto ERROR;
 	name = dash + 1;
@@ -174,6 +184,9 @@ int sensors_snprintf_chip_name(char *str, size_t size,
 	case SENSORS_BUS_TYPE_VIRTUAL:
 		return snprintf(str, size, "%s-virtual-%x", chip->prefix,
 				chip->addr);
+	case SENSORS_BUS_TYPE_ACPI:
+		return snprintf(str, size, "%s-acpi-%x", chip->prefix,
+				chip->addr);
 	}
 
 	return -SENSORS_ERR_CHIP_NAME;
@@ -194,7 +207,8 @@ int sensors_parse_bus_id(const char *name, sensors_bus_id *bus)
 	return 0;
 }
 
-int sensors_substitute_chip(sensors_chip_name *name, int lineno)
+static int sensors_substitute_chip(sensors_chip_name *name,
+				   const char *filename, int lineno)
 {
 	int i, j;
 	for (i = 0; i < sensors_config_busses_count; i++)
@@ -203,7 +217,8 @@ int sensors_substitute_chip(sensors_chip_name *name, int lineno)
 			break;
 
 	if (i == sensors_config_busses_count) {
-		sensors_parse_error("Undeclared bus id referenced", lineno);
+		sensors_parse_error_wfn("Undeclared bus id referenced",
+					filename, lineno);
 		name->bus.nr = SENSORS_BUS_NR_IGNORE;
 		return -SENSORS_ERR_BUS_NAME;
 	}
@@ -223,14 +238,20 @@ int sensors_substitute_chip(sensors_chip_name *name, int lineno)
 	return 0;
 }
 
+/* Bus substitution is on a per-configuration file basis, so we keep
+   memory (in sensors_config_chips_subst) of which chip entries have been
+   already substituted. */
 int sensors_substitute_busses(void)
 {
 	int err, i, j, lineno;
 	sensors_chip_name_list *chips;
+	const char *filename;
 	int res = 0;
 
-	for (i = 0; i < sensors_config_chips_count; i++) {
-		lineno = sensors_config_chips[i].lineno;
+	for (i = sensors_config_chips_subst;
+	     i < sensors_config_chips_count; i++) {
+		filename = sensors_config_chips[i].line.filename;
+		lineno = sensors_config_chips[i].line.lineno;
 		chips = &sensors_config_chips[i].chips;
 		for (j = 0; j < chips->fits_count; j++) {
 			/* We can only substitute if a specific bus number
@@ -238,10 +259,12 @@ int sensors_substitute_busses(void)
 			if (chips->fits[j].bus.nr == SENSORS_BUS_NR_ANY)
 				continue;
 
-			err = sensors_substitute_chip(&chips->fits[j], lineno);
+			err = sensors_substitute_chip(&chips->fits[j],
+						      filename, lineno);
 			if (err)
 				res = err;
 		}
 	}
+	sensors_config_chips_subst = sensors_config_chips_count;
 	return res;
 }
